@@ -1,4 +1,4 @@
 from .base import get_repo
-from .cache import CacheToDisk
+from .cache import CacheColumns, CacheToDisk
 from .checksum import CacheAndCheck, checksum
 from .registry import gather_datasets, register
