@@ -40,3 +40,8 @@ PhysioNet_RHD_150 = License(
     name='PhysioNet Restricted Health Data License 1.5.0',
     url='https://www.physionet.org/about/licenses/physionet-restricted-health-data-license-150/',
 )
+
+StanfordDSResearch = License(
+    name='Stanford University Dataset Research Use Agreement',
+    url='https://stanfordaimi.azurewebsites.net/datasets/e8ca74dc-8dd4-4340-815a-60b41f6cb2aa',  # TODO: separate link
+)
